Lorem ipsum dolor sit amet consectetur, adipisicing elit. Debitis nihil cupiditate earum nobis et, consequatur fuga possimus error eius expedita voluptatum id nam natus? Ipsum quo unde assumenda libero deserunt!

# Read pointer position
Lorem ipsum dolor sit amet consectetur, adipisicing elit. Debitis nihil cupiditate earum nobis et, consequatur fuga possimus error eius expedita voluptatum id nam natus? Ipsum quo unde assumenda libero deserunt!

``````
Lorem ipsum dolor sit amet consectetur, adipisicing elit. Debitis nihil cupiditate earum nobis et, consequatur fuga possimus error eius expedita voluptatum id nam natus? Ipsum quo unde assumenda libero deserunt!
``````